@@ -26,6 +26,7 @@ use phpDocumentor\Reflection\DocBlock\Tags\Return_;
 use phpDocumentor\Reflection\DocBlock\Tags\See;
 use phpDocumentor\Reflection\DocBlock\Tags\Since;
 use phpDocumentor\Reflection\DocBlock\Tags\Template;
+use phpDocumentor\Reflection\Exception\ParserException;
 use phpDocumentor\Reflection\PseudoTypes\ConstExpression;
 use phpDocumentor\Reflection\Types\Array_;
 use phpDocumentor\Reflection\Types\Compound;
@@ -85,7 +86,7 @@ DOCBLOCK;
         /** @var Description $description */
         $description;
 
-        include(__DIR__ . '/../../examples/01-interpreting-a-simple-docblock.php');
+        include(__DIR__ . '/../../docs/examples/01-interpreting-a-simple-docblock.php');
 
         $descriptionText = <<<DESCRIPTION
 This is a Description. A Summary and Description are separated by either
@@ -119,7 +120,7 @@ DESCRIPTION;
         /** @var See[] $seeTags */
         $seeTags;
 
-        include(__DIR__ . '/../../examples/02-interpreting-tags.php');
+        include(__DIR__ . '/../../docs/examples/02-interpreting-tags.php');
 
         $this->assertTrue($hasSeeTag);
         $this->assertCount(1, $tags);
@@ -146,7 +147,7 @@ DESCRIPTION;
         /** @var string $foundDescription */
         $foundDescription;
 
-        include(__DIR__ . '/../../examples/playing-with-descriptions/02-escaping.php');
+        include(__DIR__ . '/../../docs/examples/playing-with-descriptions/02-escaping.php');
 
         $this->assertSame(
             str_replace(
@@ -216,14 +217,13 @@ DOC;
             [
                 new Method(
                     'setInteger',
-                    [],
+                    [
+                        new MethodParameter('integer', new Integer())
+                    ],
                     new Void_(),
                     false,
                     new Description(''),
                     false,
-                    [
-                        new MethodParameter('integer', new Integer())
-                    ]
                 ),
             ],
             $docblock->getTags()
@@ -242,18 +242,26 @@ DOC;
         $factory = DocBlockFactory::createInstance();
         $docblock = $factory->create($docComment);
 
-        self::assertEquals(
-            [
-                InvalidTag::create(
-                    'array\Foo> $test',
-                    'param',
-                )->withError(
-                    new \InvalidArgumentException(
-                        'Could not find type in array\Foo> $test, please check for malformed notations')
-                ),
-            ],
-            $docblock->getTags()
-        );
+        $tags = $docblock->getTags();
+
+        self::assertCount(1, $docblock->getTags());
+        self::assertInstanceOf(InvalidTag::class, $tags[0]);
+        self::assertCount(1, $docblock->getTags());
+        self::assertSame('Failed to parse docblock: Unexpected token ">", expected variable at offset 16 on line 1', $tags[0]->getException()->getMessage());
+
+
+//        self::assertEquals(
+//            [
+//                InvalidTag::create(
+//                    'array\Foo> $test',
+//                    'param',
+//                )->withError(
+//                    new ParserException(
+//                        'Could not find type in array\Foo> $test, please check for malformed notations', 'aa', 1)
+//                ),
+//            ],
+//            $docblock->getTags()
+//        );
     }
 
     public function testConstantReferenceTypes(): void
@@ -335,7 +343,7 @@ DOC;
                     ),
                     new Param(
                         'args',
-                        new Compound([new Array_(new Mixed_()), new String_()]),
+                        new Compound([new Array_(), new String_()]),
                         false,
                         new Description(
                             '{' . "\n" .
@@ -356,7 +364,7 @@ DOC;
                         )
                     ),
                     new Return_(
-                        new Compound([new Array_(new Mixed_()), new Object_(new Fqsen('\WP_Error'))]),
+                        new Compound([new Array_(), new Object_(new Fqsen('\WP_Error'))]),
                         new Description('The result (also stored in `WP_Upgrader::$result`), or a WP_Error on failure.')
                     ),
                 ],
@@ -407,7 +415,7 @@ identifier has already been registered.',
                     new Since('6.5.0', new Description('')),
                     new Param(
                         'deps',
-                        new Array_(new Mixed_()),
+                        new Array_(),
                         false,
                         new Description("{
     Optional. List of dependencies.
