@@ -22,10 +22,23 @@ use phpDocumentor\Reflection\Assets\CustomServiceInterface;
 use phpDocumentor\Reflection\Assets\CustomTagFactory;
 use phpDocumentor\Reflection\DocBlock\Tags\Author;
 use phpDocumentor\Reflection\DocBlock\Tags\Deprecated;
+use phpDocumentor\Reflection\DocBlock\Tags\Extends_;
 use phpDocumentor\Reflection\DocBlock\Tags\Formatter;
 use phpDocumentor\Reflection\DocBlock\Tags\Formatter\PassthroughFormatter;
 use phpDocumentor\Reflection\DocBlock\Tags\Generic;
+use phpDocumentor\Reflection\DocBlock\Tags\Implements_;
+use phpDocumentor\Reflection\DocBlock\Tags\Method;
+use phpDocumentor\Reflection\DocBlock\Tags\Mixin;
+use phpDocumentor\Reflection\DocBlock\Tags\Param;
+use phpDocumentor\Reflection\DocBlock\Tags\Property;
+use phpDocumentor\Reflection\DocBlock\Tags\PropertyRead;
+use phpDocumentor\Reflection\DocBlock\Tags\PropertyWrite;
+use phpDocumentor\Reflection\DocBlock\Tags\Return_;
 use phpDocumentor\Reflection\DocBlock\Tags\See;
+use phpDocumentor\Reflection\DocBlock\Tags\Template;
+use phpDocumentor\Reflection\DocBlock\Tags\TemplateCovariant;
+use phpDocumentor\Reflection\DocBlock\Tags\Throws;
+use phpDocumentor\Reflection\DocBlock\Tags\Var_;
 use phpDocumentor\Reflection\Fqsen;
 use phpDocumentor\Reflection\FqsenResolver;
 use phpDocumentor\Reflection\TypeResolver;
@@ -544,4 +557,43 @@ class StandardTagFactoryTest extends TestCase
             ['@tag@invalid'],
         ];
     }
+
+    /**
+     * @param class-string $expectedClass
+     *
+     * @dataProvider provideCreateWithTagWithTypesData
+     */
+    public function testCreateWithTagWithTypes(string $input, string $expectedClass): void
+    {
+        $tagFactory = StandardTagFactory::createInstance(new FqsenResolver());
+        $tag = $tagFactory->create($input);
+
+        $this->assertInstanceOf($expectedClass, $tag);
+    }
+
+    /**
+     * @return list<array{string, class-string}>
+     */
+    public static function provideCreateWithTagWithTypesData(): array
+    {
+        return [
+            ['@mixin Foo', Mixin::class],
+            ['@method string do()', Method::class],
+            ['@param Foo $bar', Param::class],
+            ['@property-read Foo $bar', PropertyRead::class],
+            ['@property Foo $bar', Property::class],
+            ['@property-write Foo $bar', PropertyWrite::class],
+            ['@return string', Return_::class],
+            ['@throws Throwable', Throws::class],
+            ['@var string $var', Var_::class],
+            ['@template T', Template::class],
+            ['@template-covariant T', TemplateCovariant::class],
+            ['@extends Foo<Bar>', Extends_::class],
+            ['@implements Foo<Bar>', Implements_::class],
+
+            // TODO: add factories for this tags
+            // ['@template-extends Foo', TemplateExtends::class],
+            // ['@template-implements Foo', TemplateImplements::class],
+        ];
+    }
 }
